==> haskell-tasty-discover-5.0.2-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-discover.sh <==
#!/bin/sh
export PATH='/build/haskell-tasty-discover/src/tasty-discover-5.0.2/dist/build/tasty-discover:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-discover
version:              5.0.2
visibility:           public
id:                   tasty-discover-5.0.2-ANQWFD49FezJEkv0x4pG4T
key:                  tasty-discover-5.0.2-ANQWFD49FezJEkv0x4pG4T
license:              MIT
copyright:
    2016 Luke Murphy
    2020-2022 John Ky

maintainer:           John Ky <newhoggy@gmail.com>
author:               Luke Murphy
stability:            Experimental
homepage:             https://github.com/haskell-works/tasty-discover
synopsis:             Test discovery for the tasty framework.
description:
    Automatic test discovery and runner for the tasty framework.
    Prefix your test case names and tasty-discover will discover, collect and run them.
    All popular test libraries are covered. Configure once and then just write your tests.
    Avoid forgetting to add test modules to your Cabal/Hpack files.
    Tasty ingredients are included along with various configuration options for different
    use cases.
    Please see the `README.md` below for how to get started.

category:             Testing
abi:                  dba6caea80272042316344ec59adf61f
exposed:              True
exposed-modules:
    Test.Tasty.Discover Test.Tasty.Discover.Internal.Config
    Test.Tasty.Discover.Internal.Driver
    Test.Tasty.Discover.Internal.Generator
    Test.Tasty.Discover.TastyInfo Test.Tasty.Discover.Version

hidden-modules:       Paths_tasty_discover
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-discover-5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-discover-5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-discover-5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-discover
hs-libraries:         HStasty-discover-5.0.2-ANQWFD49FezJEkv0x4pG4T
depends:
    Glob-0.10.2-6Zv9O2d7h925fnVEeJHvGp base-4.17.2.1 containers-0.6.7
    filepath-1.4.2.2 tasty-1.5.2-D1ddIl7BZufDCtCc7b5fcm

haddock-interfaces:
    /usr/share/doc/haskell-tasty-discover/html/tasty-discover.haddock

haddock-html:         /usr/share/doc/haskell-tasty-discover/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-discover-5.0.2-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-discover.sh <==
#!/bin/sh
export PATH='/build/haskell-tasty-discover/src/tasty-discover-5.0.2/dist/build/tasty-discover:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-discover
version:              5.0.2
visibility:           public
id:                   tasty-discover-5.0.2-J3p3zHcyIoD74N4kI2L24Q
key:                  tasty-discover-5.0.2-J3p3zHcyIoD74N4kI2L24Q
license:              MIT
copyright:
    2016 Luke Murphy
    2020-2022 John Ky

maintainer:           John Ky <newhoggy@gmail.com>
author:               Luke Murphy
stability:            Experimental
homepage:             https://github.com/haskell-works/tasty-discover
synopsis:             Test discovery for the tasty framework.
description:
    Automatic test discovery and runner for the tasty framework.
    Prefix your test case names and tasty-discover will discover, collect and run them.
    All popular test libraries are covered. Configure once and then just write your tests.
    Avoid forgetting to add test modules to your Cabal/Hpack files.
    Tasty ingredients are included along with various configuration options for different
    use cases.
    Please see the `README.md` below for how to get started.

category:             Testing
abi:                  70b23f1658ec08ffdec2752b1f83c501
exposed:              True
exposed-modules:
    Test.Tasty.Discover Test.Tasty.Discover.Internal.Config
    Test.Tasty.Discover.Internal.Driver
    Test.Tasty.Discover.Internal.Generator
    Test.Tasty.Discover.TastyInfo Test.Tasty.Discover.Version

hidden-modules:       Paths_tasty_discover
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-discover-5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-discover-5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-discover-5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-discover
hs-libraries:         HStasty-discover-5.0.2-J3p3zHcyIoD74N4kI2L24Q
depends:
    Glob-0.10.2-GVErYq8beGKEFh7ozQbSk5 base-4.17.2.1 containers-0.6.7
    filepath-1.4.2.2 tasty-1.5.2-8LUxIBq8GAq2hXWrqvpaoX

haddock-interfaces:
    /usr/share/doc/haskell-tasty-discover/html/tasty-discover.haddock

haddock-html:         /usr/share/doc/haskell-tasty-discover/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
